about summary refs log tree commit diff homepage
path: root/test/Feature/WriteCov.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/Feature/WriteCov.c')
-rw-r--r--test/Feature/WriteCov.c19
1 files changed, 10 insertions, 9 deletions
diff --git a/test/Feature/WriteCov.c b/test/Feature/WriteCov.c
index 45e7bc43..3ecce3fc 100644
--- a/test/Feature/WriteCov.c
+++ b/test/Feature/WriteCov.c
@@ -1,20 +1,21 @@
 // RUN: %llvmgcc %s -emit-llvm -g -c -o %t2.bc
 // RUN: %klee --exit-on-error --write-cov %t2.bc
 // RUN: grep -c WriteCov.c:15  %T/klee-last/test000001.cov %T/klee-last/test000002.cov  >%t3.txt
 // RUN: grep -c WriteCov.c:17  %T/klee-last/test000001.cov %T/klee-last/test000002.cov >>%t3.txt
 // RUN: grep klee-last/test000001.cov:0 %t3.txt
 // RUN: grep klee-last/test000001.cov:1 %t3.txt
 // RUN: grep klee-last/test000002.cov:0 %t3.txt
 // RUN: grep klee-last/test000002.cov:1 %t3.txt
 
 #include <assert.h>
 #include <stdio.h>
 
 int main() {
   if (klee_range(0,2, "range")) {
-    assert(__LINE__ == 15); printf("__LINE__ = %d\n", __LINE__);
+    assert(__LINE__ == 16); printf("__LINE__ = %d\n", __LINE__);
   } else {
-    assert(__LINE__ == 17); printf("__LINE__ = %d\n", __LINE__);
+    assert(__LINE__ == 18); printf("__LINE__ = %d\n", __LINE__);
   }
   return 0;
 }
@@ -1,20 +1,21 @@
 // RUN: %llvmgcc %s -emit-llvm -g -c -o %t2.bc
-// RUN: %klee --exit-on-error --write-cov %t2.bc
-// RUN: grep -c WriteCov.c:15  %T/klee-last/test000001.cov %T/klee-last/test000002.cov  >%t3.txt
-// RUN: grep -c WriteCov.c:17  %T/klee-last/test000001.cov %T/klee-last/test000002.cov >>%t3.txt
-// RUN: grep klee-last/test000001.cov:0 %t3.txt
-// RUN: grep klee-last/test000001.cov:1 %t3.txt
-// RUN: grep klee-last/test000002.cov:0 %t3.txt
-// RUN: grep klee-last/test000002.cov:1 %t3.txt
+// RUN: rm -rf %t.klee-out
+// RUN: %klee --output-dir=%t.klee-out --exit-on-error --write-cov %t2.bc
+// RUN: grep -c WriteCov.c:16  %t.klee-out/test000001.cov %t.klee-out/test000002.cov  >%t3.txt
+// RUN: grep -c WriteCov.c:18  %t.klee-out/test000001.cov %t.klee-out/test000002.cov >>%t3.txt
+// RUN: grep %t.klee-out/test000001.cov:0 %t3.txt
+// RUN: grep %t.klee-out/test000001.cov:1 %t3.txt
+// RUN: grep %t.klee-out/test000002.cov:0 %t3.txt
+// RUN: grep %t.klee-out/test000002.cov:1 %t3.txt
 
 #include <assert.h>